<?php

namespace Mbl\Profile;

add_action( 'mbl_options_submenu_after', 'Mbl\Profile\settings_page_submenu' );
function settings_page_submenu() {
	$hs = add_submenu_page(
		'edit.php?post_type=wpm-page',
		__( 'Профиль', 'mbl_admin' ),
		__( 'Профиль', 'mbl_admin' ),
		'manage_options',
		'wpm-profile',
		'Mbl\Profile\settings_page'
	);
    add_action("load-{$hs}", 'Mbl\Profile\page_scripts');
}

function page_scripts(): void {
    wp_enqueue_script(
            'mblpr-profile',
        MBLPR_PLUGIN_URI . 'js/mblpr-profile.js',
        ['jquery-ui-droppable', 'jquery-ui-sortable', 'jquery-ui-tabs', 'icons-dialog'],
        MBLPR_VERSION
    );
    wp_enqueue_style(
            'mblpr-profile',
        MBLPR_PLUGIN_URI . 'css/mblpr-profile.css',
        [],
        MBLPR_VERSION
    );
}

function all_fields(): array {
	$fields = [
		[ 'field' => 'first_name', 'label' => 'Имя' ],
		[ 'field' => 'last_name', 'label' => 'Фамилия' ],
		[ 'field' => 'surname', 'label' => 'Отчество' ],
		[ 'field' => 'user_nicename', 'label' => 'Ник' ],
		[ 'field' => 'display_name', 'label' => 'Отображать как' ],
		[ 'field' => 'user_email', 'label' => 'Email' ],
		[ 'field' => 'phone', 'label' => 'Телефон' ],
		[ 'field' => 'avatar', 'label' => 'Аватар' ],
		[ 'field' => 'user_pass', 'label' => wpm_get_option('profile.new_pass', 'Повторить пароль') ],
		[ 'field' => 'chat_id', 'label' => 'Telegram Chat ID' ],
	];
	foreach ( range( 1, 10 ) as $item ) {
		$opt = wpm_get_option( "registration_form.custom{$item}_label" );
		if ( ! empty( $opt ) ) {
			$fields[] = [ 'field' => "custom{$item}", 'label' => $opt ];
		}
	}
	$opt = wpm_get_option( "registration_form.custom1textarea_label" );
	if ( ! empty( $opt ) ) {
		$fields[] = [ 'field' => "custom1textarea", 'label' => $opt ];
	}

	return array_reduce( $fields, function ( $c, $i ) {
		$c[ $i['field'] ] = $i;

		return $c;
	}, [] );
}

function settings_page(): void {
	if (!empty($_POST) && wp_verify_nonce( $_POST['mblpr_action_save'], 'mblpr_save_shortcodes')) {
        $options = $_POST['mblpr_shortcodes'] ?? [];
		update_option('mblpr_shortcodes', apply_filters('mblpr_update_options', $options), false);
    }
	$range  = range( 1, 10 );
	$fields = [
		[ 'field' => 'first_name', 'label' => 'Имя' ],
		[ 'field' => 'last_name', 'label' => 'Фамилия' ],
		[ 'field' => 'surname', 'label' => 'Отчество' ],
		[ 'field' => 'user_nicename', 'label' => 'Ник' ],
		[ 'field' => 'display_name', 'label' => 'Отображать как' ],
		[ 'field' => 'user_email', 'label' => 'Email' ],
		[ 'field' => 'phone', 'label' => 'Телефон' ],
		[ 'field' => 'avatar', 'label' => 'Аватар' ],
		[ 'field' => 'user_pass', 'label' => wpm_get_option('profile.new_pass', 'Повторить пароль') ],
		[ 'field' => 'chat_id', 'label' => 'Telegram Chat ID' ],
	];
	foreach ( range( 1, 10 ) as $item ) {
		$opt = wpm_get_option( "registration_form.custom{$item}_label" );
		if ( ! empty( $opt ) ) {
			$fields[] = [ 'field' => "custom{$item}", 'label' => $opt ];
		}
	}
	$opt = wpm_get_option( "registration_form.custom1textarea_label" );
	if ( ! empty( $opt ) ) {
		$fields[] = [ 'field' => "custom1textarea", 'label' => $opt ];
	}
	$fields_by_id = array_reduce( $fields, function ( $c, $i ) {
		$c[ $i['field'] ] = $i;

		return $c;
	}, [] );
	$options      = get_option( 'mblpr_shortcodes', [] );
	?>
    <div class="wpm-ui-wrap">
        <div class="wpm-inner-tabs">
            <form method="post" action="" class="wpm-settings-form mblpr-color-content" id="setting-tabs">
                <ul class="wpm-inner-tabs-nav">
			        <?php foreach ( $range as $i ): ?>
                        <li role="tab" class="tabs-li">
                            <a href="#shortcode_<?= $i ?>" type="button" class="tabs__button active">
                                Шорткод <?= $i ?>
                            </a>
                        </li>
			        <?php endforeach; ?>
                </ul>
                <div style="padding-top: 20px;">
			        <?php foreach ( $range as $i ): ?>
                        <div id="shortcode_<?= $i ?>" data-constructor="<?= $i ?>" class="ui-tabs-panel">
                            <p class="mblpr-shortcode">Шорткод: [memberlux_profile_form_<?= $i ?>]</p>
                            <div class="mblpr-fields-wrap">
                                <div class="mblpr-fields">
                                    <div>
								        <?php foreach ( $fields as $field ): ?>
                                            <div data-id="<?= $field['field'] ?>"
                                                 class="mblpr-field ui-state-highlight<?=
									             isset( $options[ $i ]['order'] ) && in_array( $field['field'], $options[ $i ]['order'] )
										             ? ' mblpr-disabled'
										             : ''
									             ?>"
                                                 data-item='<?= esc_attr( json_encode( $field ) ) ?>'>
										        <?= $field['label'] ?>
                                            </div>
								        <?php endforeach; ?>
                                    </div>
                                    <div class="wpm-tab-footer">
                                        <button type="submit" class="button button-primary wpm-save-options">Сохранить</button>
                                        <span class="buttom-preloader"></span>
                                    </div>
                                </div>
                                <div class="mblpr-sortable-wrap">
                                    <div class="mblpr-sortable" data-sortable="<?= $i ?>">
								        <?php if ( isset( $options[ $i ] ) ): ?>
									        <?php foreach ( $options[ $i ]['order'] as $key ): ?>
                                                <div data-id="<?= $key ?>" class="mblpr-field-edit">
                                                    <span class="dashicons dashicons-move"></span>
                                                    <input type="hidden" name="mblpr_shortcodes[<?= $i ?>][order][]"
                                                           value="<?= $key ?>">
	                                                <?php if ( $key !== 'display_name' ): ?>
                                                        <label data-icon="" class="mblpr-field-icon">
                                                            <span class="fa<?= ' ' . $options[ $i ][ $key ]['icon'] ?>"></span>
                                                            <button type="button">Иконка</button>
                                                            <input type="hidden"
                                                                   name="mblpr_shortcodes[<?= $i ?>][<?= $key ?>][icon]"
                                                                   value="<?= $options[ $i ][ $key ]['icon']; ?>">
                                                        </label>
                                                    <?php endif; ?>
                                                    <div class="mblpr-field-wrap ">
                                                        <label for="">
                                                            <input type="text"
                                                                   value="<?= $options[ $i ][ $key ]['label'] ?>"
                                                                   placeholder="<?= $fields_by_id[ $key ]['label'] ?>"
                                                                   name="mblpr_shortcodes[<?= $i ?>][<?= $key ?>][label]">
                                                        </label>
                                                    </div>
                                                    <div class="mblpr-required">Обязательное
                                                        <input type="hidden"
                                                               name="mblpr_shortcodes[<?= $i ?>][<?= $key ?>][required]"
                                                               value="0"/>
                                                        <label><input type="checkbox"
														        <?php if ( in_array( $key, [
															        'user_email',
															        'user_nicename'
														        ] ) ): ?>
                                                                    checked disabled
														        <?php else: ?>
															        <?= checked( $options[ $i ][ $key ]['required'], 1 ) ?>
														        <?php endif; ?>
                                                                      name="mblpr_shortcodes[<?= $i ?>][<?= $key ?>][required]"
                                                                      value="1"/>
                                                        </label>
                                                    </div>
                                                    <button data-remove="<?= $key ?>" type="button" class="mblpr-trash"><span
                                                                class="dashicons dashicons-trash"></span></button>
                                                </div>
									        <?php endforeach; ?>
								        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
			        <?php endforeach; ?>
                </div>
                <input type="hidden" name="_action" value="mblpr_save_shortcodes">
	            <?php wp_nonce_field('mblpr_save_shortcodes', 'mblpr_action_save'); ?>
            </form>
        </div>
    </div>
	<?php wpm_render_partial('icons-dialog', 'admin') ?>
	<?php
}
