<?php

namespace Mbl\Profile;


class Core {
	private Plugin $plugin;

	public function __construct( Plugin $plugin ) {
		$this->plugin = $plugin;
	}

	public function run(): void {
		add_action( 'init', [ $this, 'init' ], 1 );
		register_activation_hook( MBLPR_PLUGIN_FILE, [ $this->plugin, 'activate' ] );
		register_deactivation_hook( MBLPR_PLUGIN_FILE, [ $this->plugin, 'deactivate' ] );
	}

	public function init(): void {
		if ( $this->_pluginEnabled() ) {
			require_once $this->plugin->path( 'settings.php' );
			require_once $this->plugin->path( 'design.php' );
			require_once $this->plugin->path( 'shortcodes.php' );
		} elseif ( is_admin() ) {
			add_action( 'admin_notices', array( $this, 'notActiveNotice' ) );
		}
	}

	public function notActiveNotice(): void {
		$class   = 'notice notice-error';
		$message = __( 'МОДУЛЬ ЛИЧНОГО КАБИНЕТА не активирован!', 'mbl_admin' );

		if ( ! defined( 'WP_MEMBERSHIP_VERSION' ) ) {
			$message .= ' ' . __( 'Не установлен плагин MEMBERLUX.', 'mbl_admin' );
		} elseif ( version_compare( get_option( 'wpm_version' ), '2.3.4', '<' ) ) {
			$message .= ' ' . __( 'Устаревшая версия MEMBERLUX.', 'mbl_admin' );
		} elseif ( ! $this->_pluginKeyActive() ) {
			$message .= ' ' . __( 'Ключ не активирован.', 'mbl_admin' );
		}
		printf( '<div class="%1$s"><p>%2$s</p></div>', esc_attr( $class ), esc_html( $message ) );
	}

	private function _pluginEnabled(): bool {
		return defined( 'WP_MEMBERSHIP_VERSION' )
		       && ! version_compare( get_option( 'wpm_version' ), '2.3.4', '<' )
		       && $this->_pluginKeyActive();
	}

    private function _pluginKeyActive(): bool
    {
        $activeKeys = wpm_array_pluck(wpm_array_get(wpm_get_key_data(), 'keys.active', array()), 'type');

        if (count(wpm_array_filter($activeKeys, 'fullpackaccess'))) {
            return true;
        }

        return (bool)count(wpm_array_filter($activeKeys, 'lkabinet'));
    }
}
